@@ -116,7 +116,6 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
         if rows_synced % 100 == 0:
             singer.write_state(state)
 
-    LOGGER.info("value updated in seq_number_bookmarks: %s",seq_number_bookmarks[shard['ShardId']])
     singer.write_state(state)
     return rows_synced
 
@@ -216,6 +215,7 @@ def sync(config, state, stream):
         state = singer.write_bookmark(state, table_name, 'finished_shards', finished_shard_bookmarks)
         LOGGER.info("got seq_number_bookmarks after sync shard : %s", seq_number_bookmarks)
         if seq_number_bookmarks.get(shard['ShardId']):
+            LOGGER.info("get seq after sync hard :%s",seq_number_bookmarks)
             seq_number_bookmarks.pop(shard['ShardId'])
             state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
         singer.write_state(state)
